@@ -19,6 +19,3 @@ def flider():
         except Exception as e:
             print(e)
             print('Error on: ' + save_paths[i] + file_names[i])
-
-if __name__=='__main__':
-    flider()
\ No newline at end of file
